@@ -109,8 +109,8 @@ makeEditRow <- function(edt){
 #'
 #' The second form is the prefered form, because it allows the documentation of constraints. This
 #' may be very useful when the incorrect observations are analyzed.
-#' If the first form is used, \code{editmatrix} internally creates the second form. This information
-#' can be retrieved by using \code{\link{editrules}}
+#' The function \code{\link{editrules}} creates/extracts the second form, which can be used to store edit rules
+#' externally or to recreate an editmatrix later on.
 #'
 #' The matrix is created by retrieving the coefficients of the variables in the equalities.
 #' i.e. \code{x == y}   results in  \code{c(x=1, y=-1)}
@@ -145,24 +145,14 @@ editmatrix <- function( editrules
       name <- editrules$name
       edit <- as.character(editrules$edit)
       description <- editrules$description
-
-      if (!length(edit)){
-         stop("The supplied data.frame misses the column 'edit'.\nSee ?editmatrix for a valid input specification")
-#      if (!length(name))
-#         name <- paste("e",1:length(edit),sep="")
-#      if (!length(description))
-#         description <- character(length(edit))
      }            
-    }
+    
    else {
       stop("Invalid input, please use a character vector or a data.frame.\n See ?editmatrix for a valid input specification")
    }
 
-   edts <- tryCatch(parse(text=edit), error=function(e){
-         stop(paste("The edits could not be parsed. Parser returned\n",e$message))})   
+   edts <- parseEdits(edit)
 
-   stopifnot(is.language(edts))
-   
    edit <- sapply(edts, deparse, width.cutoff=500)
    edit <- gsub(" * ","*", fixed=TRUE, edit)
    
@@ -235,10 +225,13 @@ neweditmatrix <- function(A, ops, normalized=FALSE,...){
 #' @param ... arguments to be passed to other methods. Currently ignored.
 #' @rdname editmatrix-subscript
 `[.editmatrix` <- function(x, i, j, ...){
-    neweditmatrix(
+    E <- neweditmatrix(
         A = as.matrix(x)[i, j, drop=FALSE],
         ops = getOps(x)[i]
-        )
+    )
+    attr(E,"H") <- attr(x,"H")[i, , drop=FALSE]
+    attr(E,"h") <- attr(x,"h")
+    E
 }
 
 
@@ -253,9 +246,9 @@ is.editmatrix <- function(x){
    return(inherits(x, "editmatrix"))
 }
 
-#' Coerce to an edit matrix. This method will derive editrules from a matrix.
+#' Coerce a matrix to an edit matrix.
 #'
-#' \code{as.editmatrix} interpretes the matrix as an editmatrix and derives readable edit rules. 
+#' \code{as.editmatrix} interpretes the matrix as an editmatrix.
 #' The columns of the matrix
 #' are the variables and the rows are the edit rules (contraints).
 #' 
@@ -268,7 +261,7 @@ is.editmatrix <- function(x){
 #' @param A matrix to be transformed into an \code{\link{editmatrix}}. 
 #' @param b Constant, a \code{numeric} of \code{length(nrow(x))}, defaults to 0
 #' @param ops Operators, \code{character} of \code{length(nrow(x))} with the equality operators, defaults to "=="
-#' @param ... further parameters will be given to \code{editmatrix}
+#' @param ... further attributes that will be attached to the resulting editmatrix
 #'
 #' @return an object of class \code{editmatrix}.
 as.editmatrix <- function( A
@@ -292,7 +285,7 @@ as.editmatrix <- function( A
     }
     A <- cbind(as.matrix(A), b)
     dimnames(A) <- list(rules=rn,var=c(cn,"CONSTANT"))
-    E <- neweditmatrix(A=A, ops=ops)
+    E <- neweditmatrix(A=A, ops=ops, ...)
     if (isNormalized(E)) attr(E,"normalized") <- TRUE
     E
 }
@@ -336,8 +329,9 @@ as.data.frame.editmatrix <- function(x, ...){
 }
 
 
-#' Get character representation of editmatrix
+#' Coerce an editmatrix to a \code{character} vector
 #'
+#' Derives readable editrules from an editmatrix.
 #' @export
 #' @method as.character editmatrix
 #'
@@ -380,8 +374,9 @@ as.character.editmatrix <- function(x, ...){
    txt
 }
 
-#' Get expression representation of editmatrix
+#' Coerce an editmatrix to R expressions
 #'
+#' Generates an R \code{expression} vector that can be used to check data using \code{\link{eval}}.
 #' @export
 #' @method as.expression editmatrix
 #'
@@ -429,7 +424,3 @@ str.editmatrix <- function(object,...){
     if (nchar(vars) > 20 ) vars <-  paste(strtrim(vars,16),"...") 
     cat(paste("editmatrix with", nrow(object), "edits containing variables",vars,"\n"))
 }
-
-
-
-
