@@ -80,7 +80,6 @@ echelon.matrix <- function(E, tol=sqrt(.Machine$double.eps), ...){
 #'
 #' Note that the resulting \code{\link{editmatrix}} may be inconsistent because of inconsistencies in
 #' \eqn{\tilde{\bf x}}.
-#' @aliases replaceValue
 #' @param E \code{editmatrix} object
 #' @param var \code{character} with name(s) of variable(s)
 #' @param value \code{numeric} with value(s) of variable(s)
@@ -91,25 +90,18 @@ echelon.matrix <- function(E, tol=sqrt(.Machine$double.eps), ...){
 substValue <- function(E, var, value, remove=FALSE){
     v <- match(var, getVars(E), nomatch=0)
     if (any(v==0)){
-        stop("Parameter var (", var[v==0], ") is not a variable of editmatrix E")
+        warning("Parameter var (", var[v==0], ") is not a variable of editmatrix E")
     }
-    
+    v <- v[v != 0]
     ib <- ncol(E)
     E[,ib] <- E[ ,ib] - E[ ,v]%*%value
     
-    E[,v] <- 0     
-    if (remove){
-        E[!isObviouslyRedundant(E),-v]
-    }
-    
-    else {
-        E[!isObviouslyRedundant(E),]
-    }
+    if (remove)
+        E <- E[,-v, drop=FALSE]
+    else 
+        E[,v] <- 0
+        
+    E[!isObviouslyRedundant(E),]    
 }
 
-#' @nord
-#' @export
-replaceValue <- function(...){
-    stop("replaceValue is deprecated. Use substValue in stead.")
-}
 
