@@ -1,10 +1,10 @@
 library(testthat)
 
 test_that("Checking a data set works",{
-   edt <- editmatrix(editrules = "2*x==y")
+   edt <- editmatrix("2*x==y")
    dat <- data.frame(x=c(2,1), y=c(4,5))
-   #print(checkEdits(dat, edt)) 
-   expect_equal(checkRows(edt, dat), c(TRUE,FALSE))
+   cr <- checkRows(edt, dat)
+   expect_equal(cr, c(TRUE,FALSE))
 })
 
 test_that("Checking a vector works",{
@@ -42,4 +42,4 @@ test_that("Error lists works",{
    #expect_equal(errors, list("1"=c(2), "2"=c(1)))
    #print(str(errors))
    #print(showErrors(dat, edt)) 
-})
\ No newline at end of file
+})
